@@ -1,24 +1,26 @@
 /*
-@licstart  The following is the entire license notice for the
-JavaScript code in this file.
+ @licstart  The following is the entire license notice for the JavaScript code in this file.
 
-Copyright (C) 1997-2019 by Dimitri van Heesch
+ The MIT License (MIT)
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of version 2 of the GNU General Public License as published by
-the Free Software Foundation
+ Copyright (C) 1997-2020 by Dimitri van Heesch
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
+ Permission is hereby granted, free of charge, to any person obtaining a copy of this software
+ and associated documentation files (the "Software"), to deal in the Software without restriction,
+ including without limitation the rights to use, copy, modify, merge, publish, distribute,
+ sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
+ furnished to do so, subject to the following conditions:
 
-You should have received a copy of the GNU General Public License along
-with this program; if not, write to the Free Software Foundation, Inc.,
-51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ The above copyright notice and this permission notice shall be included in all copies or
+ substantial portions of the Software.
 
-@licend  The above is the entire license notice
-for the JavaScript code in this file
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
+ BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+ NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
+ DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+ @licend  The above is the entire license notice for the JavaScript code in this file
 */
 var NAVTREE =
 [
@@ -99,14 +101,14 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "annotated.html",
-"core_8h.html#a50323f15b69d13b86fe1d59d6dd3bfba",
-"global_8h.html#ae029163e030a00b9ef6148b128f26b60",
-"impl-node_8c.html#abd34c711e7bd7b7ae1a38ff4e1b1bfe2",
-"link_8h_source.html",
-"pipewire_8h.html#a06c879b2d800579f4724109054368d99",
-"structbuffer.html#a89e90c78766d7752205fc656265fcf6d",
-"structpw__impl__client__events.html#a64120718bec833fc87ca30ff85e01645",
-"structpw__registry__methods.html#a82488a74c02c5b764b0764b0d3e42fac"
+"core_8h.html#a4828b5ffb309b2d8a985e0ee4fc80978",
+"global_8h.html#a7c5ab037320ab252af6eb6eb1b85b0b9",
+"impl-node_8c.html#a51569338546db3fa16325394364f752b",
+"link_8h.html#a7859f6eb040fead1673d0214b83b445ba843c796704968af8538babd8f5c642e2",
+"permission_8h_source.html",
+"stream_8h.html#ab2ef0e28a1e91816f8015ef9814d18f7",
+"structpw__filter__events.html#a5a03c51cf03b2e8408ead88cc66b25cd",
+"structpw__protocol__server.html#a0ac79f449a098fd48ac49f48f56a0ed3"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
