@@ -1,13 +1,20 @@
 var NAVTREEINDEX4 =
 {
+"link_8h.html#a7859f6eb040fead1673d0214b83b445ba843c796704968af8538babd8f5c642e2":[11,0,37,17,3],
+"link_8h.html#a7859f6eb040fead1673d0214b83b445baebfc67d86c96c1d6cab229600b46a041":[11,0,37,17,2],
+"link_8h.html#a7859f6eb040fead1673d0214b83b445baec2b9ab9232c60cf2c436d785ff15ddc":[11,0,37,17,4],
+"link_8h.html#aa09465885f2b5edd3aecf62a2e8f7ef7":[11,0,37,15],
 "link_8h.html#aa90bcda1ac9edbb5f2c92703f1e38d84":[11,0,37,14],
 "link_8h.html#aafb6d5e113016baef0cf9a8cc9405c31":[11,0,37,10],
 "link_8h.html#ab53c62332a757ed234d5eb91a54a23ac":[11,0,37,3],
 "link_8h_source.html":[11,0,37],
 "log_8c.html":[11,0,38],
-"log_8c.html#a0c36ced32d7c93e93a7546e6b95ab79e":[11,0,38,1],
-"log_8c.html#ae98f1a3c52f402a7004bf30bc64f3ced":[11,0,38,2],
-"log_8c.html#afb19ed665807eb04101898b6548a614e":[11,0,38,0],
+"log_8c.html#a0c36ced32d7c93e93a7546e6b95ab79e":[11,0,38,5],
+"log_8c.html#a4723ab21869fd7093aa39c717e71e924":[11,0,38,3],
+"log_8c.html#a64fcfd120a212af3d011b6c75ebe83da":[11,0,38,4],
+"log_8c.html#a703920a6078c724a9afd62f9e27a9474":[11,0,38,1],
+"log_8c.html#ae98f1a3c52f402a7004bf30bc64f3ced":[11,0,38,6],
+"log_8c.html#afb19ed665807eb04101898b6548a614e":[11,0,38,2],
 "log_8h.html":[11,0,39],
 "log_8h.html#a0a957072ba799bbf2bdc77501ccd81d0":[11,0,39,5],
 "log_8h.html#a0baff5cd026e7187ab12ca821f942502":[11,0,39,10],
@@ -84,10 +91,10 @@ var NAVTREEINDEX4 =
 "mem_8c.html#a3268e6d65db2950f67f6082946d16952":[11,0,45,12],
 "mem_8c.html#a3318c5821ce251c9c3c16145bed41647":[11,0,45,19],
 "mem_8c.html#a3c9cb62957637bb3b3a869cbbe5e4aaa":[11,0,45,4],
+"mem_8c.html#a4795146fb79f58f2277d535f71bdea34":[11,0,45,33],
 "mem_8c.html#a47f2e62c0dbebc787052c165afcada0e":[11,0,45,13],
 "mem_8c.html#a54af789ad65b83449d415dbfb7d39481":[11,0,45,6],
 "mem_8c.html#a5c298052be6fe8f5f4ea78b4fe41733d":[11,0,45,21],
-"mem_8c.html#a5f75d7faa910a02718a9ecf3f9c4041c":[11,0,45,33],
 "mem_8c.html#a68a01fe6f7305883d5f15ddfd1ebfd84":[11,0,45,8],
 "mem_8c.html#a6ae683cd27bb82613d1c025277b69b48":[11,0,45,7],
 "mem_8c.html#a6d863d10f2d358484936fd382f55b9b5":[11,0,45,24],
@@ -119,8 +126,8 @@ var NAVTREEINDEX4 =
 "mem_8h.html#a3efb664909dd90a771d5092238a7a603":[11,0,46,10],
 "mem_8h.html#a3f4c9504cb9f261727ec4b27d0b7074d":[11,0,46,12],
 "mem_8h.html#a40f7779f907ebc367725ba5c7c8b0f88":[11,0,46,20],
+"mem_8h.html#a4795146fb79f58f2277d535f71bdea34":[11,0,46,24],
 "mem_8h.html#a5c298052be6fe8f5f4ea78b4fe41733d":[11,0,46,11],
-"mem_8h.html#a5f75d7faa910a02718a9ecf3f9c4041c":[11,0,46,24],
 "mem_8h.html#a637115c056f47906c4d52faf043e415f":[11,0,46,17],
 "mem_8h.html#a85ef7c8290e81beb53ab9e1c7b44ff29":[11,0,46,21],
 "mem_8h.html#a8cefbc9877517111668c36f24edb2dfd":[11,0,46,16],
@@ -242,12 +249,5 @@ var NAVTREEINDEX4 =
 "permission_8h.html#a77df16320c3bb338666f55b2b21e6e47":[11,0,49,6],
 "permission_8h.html#a97d33a5e044ee126fd9991b8c70424aa":[11,0,49,7],
 "permission_8h.html#aa61804de7cf6003defd8b26ef488ce56":[11,0,49,3],
-"permission_8h.html#aa6b729cf828ec6417f5ba997560fda2b":[11,0,49,9],
-"permission_8h_source.html":[11,0,49],
-"pipewire_8c.html":[11,0,50],
-"pipewire_8c.html#a11740ad8a800f1b866e3af11e02762c8":[11,0,50,6],
-"pipewire_8c.html#a5432ea68283040ae9df24ebefe6414aa":[11,0,50,5],
-"pipewire_8c.html#aa060eea150eca4951bf30b2738493912":[11,0,50,8],
-"pipewire_8c.html#ac0edd7fd875859cef79624861e212cc8":[11,0,50,7],
-"pipewire_8c.html#acbb97d3ccaef2d8793ec48242324bf15":[11,0,50,10]
+"permission_8h.html#aa6b729cf828ec6417f5ba997560fda2b":[11,0,49,9]
 };
